@@ -1,5 +1,5 @@
 /*
- * Copyright © 2014-2020 Canonical Ltd.
+ * Copyright © Canonical Ltd.
  *
  * This program is free software: you can redistribute it and/or modify it
  * under the terms of the GNU Lesser General Public License version 2 or 3,
@@ -23,6 +23,8 @@
 
 namespace mir
 {
+class SharedLibrary;
+
 namespace options
 {
 extern char const* const arw_server_socket_opt;
@@ -46,6 +48,7 @@ extern char const* const wayland_extensions_opt;
 extern char const* const add_wayland_extensions_opt;
 extern char const* const drop_wayland_extensions_opt;
 extern char const* const idle_timeout_opt;
+extern char const* const idle_timeout_when_locked_opt;
 
 extern char const* const enable_key_repeat_opt;
 
@@ -69,12 +72,19 @@ extern char const* const vt_option_name;
 class Configuration
 {
 public:
-    virtual std::shared_ptr<options::Option> the_options() const = 0;
+    /**
+     * The options not associated with a specific loaded module
+     */
+    virtual std::shared_ptr<options::Option> global_options() const = 0;
+    /**
+     * All options, including those added by the specified module
+     */
+    virtual auto options_for(SharedLibrary const& module) const -> std::shared_ptr<options::Option> = 0;
 
 protected:
-
     Configuration() = default;
     virtual ~Configuration() = default;
+
     Configuration(Configuration const&) = delete;
     Configuration& operator=(Configuration const&) = delete;
 };
