@@ -1,5 +1,5 @@
 /*
- * Copyright © 2012-2020 Canonical Ltd.
+ * Copyright © Canonical Ltd.
  *
  * This program is free software: you can redistribute it and/or modify it
  * under the terms of the GNU General Public License version 2 or 3,
@@ -17,12 +17,12 @@
 #define MIR_DEFAULT_SERVER_CONFIGURATION_H_
 
 #include "mir/cached_ptr.h"
+#include "mir/options/option.h"
 #include "mir/server_configuration.h"
 #include "mir/shell/window_manager_builder.h"
 
 #include <memory>
 #include <string>
-#include <mutex>
 
 namespace mir
 {
@@ -37,18 +37,14 @@ template<class Observer>
 class ObserverMultiplexer;
 
 class ConsoleServices;
+class DecorationStrategy;
 
-namespace cookie
-{
-class Authority;
-}
 namespace dispatch
 {
 class MultiplexingDispatchable;
 }
 namespace compositor
 {
-class BufferStreamFactory;
 class Scene;
 class DisplayBufferCompositorFactory;
 class Compositor;
@@ -57,15 +53,18 @@ class CompositorReport;
 namespace frontend
 {
 class Connector;
-class SessionAuthorizer;
-class EventSink;
 class DisplayChanger;
+class DragIconController;
+class EventSink;
 class InputConfigurationChanger;
+class PointerInputDispatcher;
+class SessionAuthorizer;
 class SurfaceStack;
 }
 
 namespace shell
 {
+class AccessibilityManager;
 class DisplayConfigurationController;
 class InputTargeter;
 class FocusController;
@@ -84,7 +83,6 @@ namespace scene
 {
 class SurfaceFactory;
 class BroadcastingSessionEventSink;
-class BufferStreamFactory;
 class MediatingDisplayChanger;
 class SessionContainer;
 class SessionEventSink;
@@ -125,7 +123,13 @@ class TouchVisualizer;
 class CursorImages;
 class Seat;
 class KeyMapper;
+class LedObserverRegistrar;
+namespace receiver
+{
+class XKBMapperRegistrar;
 }
+}
+
 
 namespace logging
 {
@@ -172,16 +176,19 @@ public:
     std::shared_ptr<MainLoop>               the_main_loop() override;
     std::shared_ptr<ServerStatusListener>   the_server_status_listener() override;
     std::shared_ptr<DisplayChanger>         the_display_changer() override;
+    std::shared_ptr<ConsoleServices>        the_console_services() override;
     std::vector<std::shared_ptr<graphics::DisplayPlatform>> const& the_display_platforms() override;
     auto the_rendering_platforms() -> std::vector<std::shared_ptr<graphics::RenderingPlatform>> const& override;
     std::shared_ptr<input::InputDispatcher> the_input_dispatcher() override;
     std::shared_ptr<EmergencyCleanup>       the_emergency_cleanup() override;
-    std::shared_ptr<cookie::Authority>      the_cookie_authority() override;
-    std::shared_ptr<scene::Clipboard>       the_clipboard() override;
+    std::shared_ptr<scene::Clipboard>       the_main_clipboard() override;
+    std::shared_ptr<scene::Clipboard>       the_primary_selection_clipboard() override;
     std::shared_ptr<scene::TextInputHub>    the_text_input_hub() override;
     std::shared_ptr<scene::IdleHub>         the_idle_hub() override;
     std::shared_ptr<shell::IdleHandler>     the_idle_handler() override;
+    std::shared_ptr<shell::TokenAuthority>  the_token_authority() override;
     std::function<void()>                   the_stop_callback() override;
+    std::shared_ptr<scene::SessionLock>     the_session_lock() override;
     void add_wayland_extension(
         std::string const& name,
         std::function<std::shared_ptr<void>(
@@ -250,6 +257,8 @@ public:
      *  @{ */
     virtual std::shared_ptr<frontend::SessionAuthorizer>      the_session_authorizer();
     virtual std::shared_ptr<frontend::DisplayChanger>         the_frontend_display_changer();
+    virtual std::shared_ptr<frontend::DragIconController>     the_drag_icon_controller();
+    virtual std::shared_ptr<frontend::PointerInputDispatcher> the_pointer_input_dispatcher();
     /** @name frontend configuration - internal dependencies
      * internal dependencies of frontend
      *  @{ */
@@ -273,6 +282,7 @@ public:
 
     virtual std::shared_ptr<shell::PersistentSurfaceStore> the_persistent_surface_store();
     virtual std::shared_ptr<shell::ShellReport>         the_shell_report();
+    virtual std::shared_ptr<shell::AccessibilityManager> the_accessibility_manager();
     /** @} */
 
     /** @name internal scene configuration
@@ -290,7 +300,6 @@ public:
     /** @name scene configuration - dependencies
      * dependencies of scene on the rest of the Mir
      *  @{ */
-    virtual std::shared_ptr<scene::BufferStreamFactory> the_buffer_stream_factory();
     virtual std::shared_ptr<scene::SceneReport>      the_scene_report();
     /** @} */
 
@@ -316,6 +325,7 @@ public:
     virtual std::shared_ptr<input::TouchVisualizer> the_touch_visualizer();
     virtual std::shared_ptr<input::Seat> the_seat();
     virtual std::shared_ptr<input::KeyMapper> the_key_mapper();
+    virtual std::shared_ptr<input::LedObserverRegistrar> the_led_observer_registrar();
 
     // new input reading related parts:
     virtual std::shared_ptr<dispatch::MultiplexingDispatchable> the_input_reading_multiplexer();
@@ -334,11 +344,14 @@ public:
     virtual std::shared_ptr<ServerActionQueue> the_server_action_queue();
     virtual std::shared_ptr<SharedLibraryProberReport>  the_shared_library_prober_report();
 
-    virtual std::shared_ptr<ConsoleServices> the_console_services();
     auto default_reports() -> std::shared_ptr<void>;
 
+    auto the_decoration_strategy() -> std::shared_ptr<DecorationStrategy> override;
+    void set_the_decoration_strategy(std::shared_ptr<DecorationStrategy> strategy) override;
+
 protected:
     std::shared_ptr<options::Option> the_options() const;
+    auto the_options_provider() const -> std::shared_ptr<options::Configuration>;
     std::shared_ptr<input::DefaultInputDeviceHub>  the_default_input_device_hub();
     std::shared_ptr<graphics::DisplayConfigurationObserver> the_display_configuration_observer();
     std::shared_ptr<input::SeatObserver> the_seat_observer();
@@ -362,6 +375,7 @@ protected:
     CachedPtr<frontend::Connector>   connector;
     CachedPtr<frontend::Connector>   wayland_connector;
     CachedPtr<frontend::Connector>   xwayland_connector;
+    CachedPtr<frontend::DragIconController> drag_icon_controller;
 
     CachedPtr<input::InputReport> input_report;
     CachedPtr<input::EventFilterChainDispatcher> event_filter_chain_dispatcher;
@@ -384,7 +398,6 @@ protected:
 
     CachedPtr<frontend::SessionAuthorizer> session_authorizer;
     CachedPtr<renderer::RendererFactory> renderer_factory;
-    CachedPtr<compositor::BufferStreamFactory> buffer_stream_factory;
     CachedPtr<scene::SurfaceStack> scene_surface_stack;
     CachedPtr<shell::SurfaceStack> surface_stack;
     CachedPtr<scene::SceneReport> scene_report;
@@ -392,10 +405,12 @@ protected:
     CachedPtr<scene::SurfaceFactory> surface_factory;
     CachedPtr<scene::SessionContainer>  session_container;
     CachedPtr<scene::SessionListener> session_listener;
-    CachedPtr<scene::Clipboard>         clipboard;
+    CachedPtr<scene::Clipboard>         main_clipboard;
+    CachedPtr<scene::Clipboard>         primary_selection_clipboard;
     CachedPtr<scene::TextInputHub>      text_input_hub;
     CachedPtr<scene::IdleHub>           idle_hub;
     CachedPtr<shell::IdleHandler>       idle_handler;
+    CachedPtr<shell::TokenAuthority>    token_authority;
     CachedPtr<shell::DisplayLayout>     shell_display_layout;
     CachedPtr<compositor::DisplayBufferCompositorFactory> display_buffer_compositor_factory;
     CachedPtr<compositor::Compositor> compositor;
@@ -417,11 +432,13 @@ protected:
     CachedPtr<SharedLibraryProberReport> shared_library_prober_report;
     CachedPtr<shell::Shell> shell;
     CachedPtr<shell::ShellReport> shell_report;
+    CachedPtr<shell::AccessibilityManager> accessibility_manager;
     CachedPtr<shell::decoration::Manager> decoration_manager;
     CachedPtr<scene::ApplicationNotRespondingDetector> application_not_responding_detector;
     CachedPtr<cookie::Authority> cookie_authority;
-    CachedPtr<input::KeyMapper> key_mapper;
+    CachedPtr<input::receiver::XKBMapperRegistrar> xkb_mapper_registrar;
     std::shared_ptr<ConsoleServices> console_services;
+    std::shared_ptr<DecorationStrategy> decoration_strategy;
 
 private:
     std::shared_ptr<options::Configuration> const configuration_options;
