@@ -1,5 +1,5 @@
 /*
- * Copyright © 2014-2019 Canonical Ltd.
+ * Copyright © Canonical Ltd.
  *
  * This program is free software: you can redistribute it and/or modify it
  * under the terms of the GNU General Public License version 2 or 3,
@@ -18,11 +18,11 @@
 #define MIR_SERVER_H_
 
 #include "mir/shell/window_manager_builder.h"
-#include "mir/optional_value.h"
 #include "mir_toolkit/common.h"
 
 #include <functional>
 #include <memory>
+#include <optional>
 #include <vector>
 
 struct wl_display;
@@ -34,23 +34,21 @@ class ObserverRegistrar;
 
 namespace compositor { class Compositor; class DisplayBufferCompositorFactory; class CompositorReport; }
 namespace graphics { class Cursor; class DisplayPlatform; class RenderingPlatform; class Display; class GLConfig; class DisplayConfigurationPolicy; class DisplayConfigurationObserver; }
-namespace input { class CompositeEventFilter; class InputDispatcher; class CursorListener; class CursorImages; class TouchVisualizer; class InputDeviceHub;}
+namespace input { class CompositeEventFilter; class InputDispatcher; class CursorListener; class CursorImages; class TouchVisualizer; class InputDeviceHub; class InputDeviceRegistry;}
 namespace logging { class Logger; }
 namespace options { class Option; }
 namespace frontend
 {
 class SessionAuthorizer;
 }
-namespace cookie
-{
-using Secret = std::vector<uint8_t>;
-class Authority;
-}
 namespace shell
 {
+class AccessibilityManager;
 class DisplayLayout;
 class DisplayConfigurationController;
 class FocusController;
+class IdleHandler;
+class TokenAuthority;
 class InputTargeter;
 class PersistentSurfaceStore;
 class Shell;
@@ -59,22 +57,27 @@ class SurfaceStack;
 namespace scene
 {
 class ApplicationNotRespondingDetector;
-class BufferStreamFactory;
 class PromptSessionListener;
 class PromptSessionManager;
 class SessionListener;
 class SessionCoordinator;
 class SurfaceFactory;
 class Session;
+class SessionLock;
 }
 namespace input
 {
 class SeatObserver;
 }
+namespace renderer
+{
+class RendererFactory;
+}
 
 class Fd;
 class MainLoop;
 class ServerStatusListener;
+class DecorationStrategy;
 
 enum class OptionType
 {
@@ -82,7 +85,8 @@ enum class OptionType
     integer,
     string,
     boolean,
-    strings
+    strings,
+    real
 };
 
 /// Customise and run a Mir server.
@@ -258,11 +262,6 @@ public:
     /// Sets an override functor for creating the gl config.
     void override_the_gl_config(Builder<graphics::GLConfig> const& gl_config_builder);
 
-    /// Sets an override functor for creating the cookie authority.
-    /// A secret can be saved and any process this secret is shared
-    /// with can verify Mir-generated cookies, or produce their own.
-    void override_the_cookie_authority(Builder<cookie::Authority> const& cookie_authority_builder);
-
     /// Sets an override functor for creating the input dispatcher.
     void override_the_input_dispatcher(Builder<input::InputDispatcher> const& input_dispatcher_builder);
 
@@ -290,7 +289,9 @@ public:
     /// Sets an override functor for creating the shell.
     void override_the_shell(Builder<shell::Shell> const& wrapper);
 
-    /// Sets an override functor for creating the window manager.
+    /// Sets an override functor for creating the window manager. If left unset, the server
+    /// will create a SystemCompositorWindowManager.
+    /// \see SystemCompositorWindowManager src/miral/system_compositor_window_manager.h
     void override_the_window_manager_builder(shell::WindowManagerBuilder const wmb);
 
     /// Sets an override functor for creating the application not responding detector.
@@ -300,6 +301,9 @@ public:
     /// Sets an override functor for creating the persistent_surface_store
     void override_the_persistent_surface_store(Builder<shell::PersistentSurfaceStore> const& persistent_surface_store);
 
+    /// Sets an override functor for the renderer_factory
+    void override_the_renderer_factory(Builder<renderer::RendererFactory> const& renderer_factory_builder);
+
     /// Each of the wrap functions takes a wrapper functor of the same form
     template<typename T> using Wrapper = std::function<std::shared_ptr<T>(std::shared_ptr<T> const&)>;
 
@@ -394,9 +398,6 @@ public:
     /// \return the display layout.
     auto the_shell_display_layout() const -> std::shared_ptr<shell::DisplayLayout>;
 
-    /// \return the buffer stream factory
-    auto the_buffer_stream_factory() const -> std::shared_ptr<scene::BufferStreamFactory>;
-
     /// \return the surface factory
     auto the_surface_factory() const -> std::shared_ptr<scene::SurfaceFactory>;
 
@@ -424,7 +425,23 @@ public:
     auto the_seat_observer_registrar() const ->
         std::shared_ptr<ObserverRegistrar<input::SeatObserver>>;
 
+    auto the_session_lock() const ->
+        std::shared_ptr<scene::SessionLock>;
 
+    auto the_renderer_factory() const ->
+        std::shared_ptr<renderer::RendererFactory>;
+
+    auto the_input_device_registry() const ->
+        std::shared_ptr<input::InputDeviceRegistry>;
+
+    auto the_idle_handler() const ->
+        std::shared_ptr<shell::IdleHandler>;
+
+    auto the_token_authority() const ->
+        std::shared_ptr<shell::TokenAuthority>;
+
+    auto the_accessibility_manager() const ->
+        std::shared_ptr<shell::AccessibilityManager>;
 /** @} */
 
 /** @name Client side support
@@ -458,15 +475,19 @@ public:
         std::function<bool(std::shared_ptr<scene::Session> const&, char const*)> const& extension_filter);
 
     /// Get the name of the Wayland endpoint (if any) usable as a $WAYLAND_DISPLAY value
-    auto wayland_display() const -> optional_value<std::string>;
+    auto wayland_display() const -> std::optional<std::string>;
 
     /// Get the name of the X11 display usable as a $DISPLAY value
-    auto x11_display() const -> optional_value<std::string>;
+    auto x11_display() const -> std::optional<std::string>;
+
+    auto get_activation_token() const -> std::string;
 
     /// Overrides the standard set of Wayland extensions (mir::frontend::get_standard_extensions()) with a new list
     void set_enabled_wayland_extensions(std::vector<std::string> const& extensions);
 /** @} */
 
+    auto the_decoration_strategy() const -> std::shared_ptr<DecorationStrategy>;
+    void set_the_decoration_strategy(std::shared_ptr<DecorationStrategy> strategy);
 private:
     struct ServerConfiguration;
     struct Self;
