@@ -1,5 +1,5 @@
 /*
- * Copyright © 2018-2019 Canonical Ltd.
+ * Copyright © Canonical Ltd.
  *
  * This program is free software: you can redistribute it and/or modify it
  * under the terms of the GNU General Public License version 3,
@@ -30,20 +30,20 @@
 #include <set>
 #include <map>
 #include <vector>
+#include <iterator>
 
 namespace mo = mir::options;
 
 char const* const miral::WaylandExtensions::zwlr_layer_shell_v1{"zwlr_layer_shell_v1"};
 char const* const miral::WaylandExtensions::zxdg_output_manager_v1{"zxdg_output_manager_v1"};
 char const* const miral::WaylandExtensions::zwlr_foreign_toplevel_manager_v1{"zwlr_foreign_toplevel_manager_v1"};
-/// Not in the header, but keeping around for ABI compat
-char const* const miral::WaylandExtensions::zwp_virtual_keyboard_v1{"zwp_virtual_keyboard_manager_v1"};
 char const* const miral::WaylandExtensions::zwp_virtual_keyboard_manager_v1{"zwp_virtual_keyboard_manager_v1"};
-/// Not in the header, but keeping around for ABI compat
-char const* const miral::WaylandExtensions::zwp_input_method_v2{"zwp_input_method_manager_v2"};
+char const* const miral::WaylandExtensions::zwp_input_method_v1{"zwp_input_method_v1"};
+char const* const miral::WaylandExtensions::zwp_input_panel_v1{"zwp_input_panel_v1"};
 char const* const miral::WaylandExtensions::zwp_input_method_manager_v2{"zwp_input_method_manager_v2"};
 char const* const miral::WaylandExtensions::zwlr_screencopy_manager_v1{"zwlr_screencopy_manager_v1"};
 char const* const miral::WaylandExtensions::zwlr_virtual_pointer_manager_v1{"zwlr_virtual_pointer_manager_v1"};
+char const* const miral::WaylandExtensions::ext_session_lock_manager_v1{"ext_session_lock_manager_v1"};
 
 namespace
 {
@@ -261,16 +261,6 @@ struct miral::WaylandExtensions::Self
         }
     }
 
-    void assert_only_one_extension_filter_type_used()
-    {
-        if (!conditional_extensions.empty() && extensions_filter)
-        {
-            BOOST_THROW_EXCEPTION(std::logic_error(
-                "Only one of WaylandExtensions::conditionally_enable() or WaylandExtensions::filter() can be used. "
-                "Convert your use of the deprecated filter() method to conditionally_enable()"));
-        }
-    }
-
     void init_server(mir::Server& server)
     {
         for (auto const& hook : wayland_extension_hooks)
@@ -487,20 +477,6 @@ void miral::WaylandExtensions::add_extension(Builder const& builder)
     self->enable_extension(builder.name);
 }
 
-void miral::WaylandExtensions::set_filter(miral::WaylandExtensions::Filter const& extension_filter)
-{
-    // Wayland calls the filter for all protocols (not just the optional extensions).
-    // To avoid accidents (like denying base protocols) we only defer to the provided
-    // extension_filter for supported_extensions.
-    self->extensions_filter = [&optional = self->supported_extensions, extension_filter]
-        (Application const& app, char const* protocol)
-        {
-            return (optional.count(protocol) == 0) || extension_filter(app, protocol);
-        };
-
-    self->assert_only_one_extension_filter_type_used();
-}
-
 void miral::WaylandExtensions::add_extension_disabled_by_default(miral::WaylandExtensions::Builder const& builder)
 {
     self->add_extension(builder);
@@ -533,7 +509,6 @@ auto miral::WaylandExtensions::conditionally_enable(
     EnableCallback const& callback) -> WaylandExtensions&
 {
     self->conditionally_enable(name, callback);
-    self->assert_only_one_extension_filter_type_used();
     return *this;
 }
 
