@@ -1,5 +1,5 @@
 /*
- * Copyright © 2013-2020 Canonical Ltd.
+ * Copyright © Canonical Ltd.
  *
  * This program is free software: you can redistribute it and/or modify it
  * under the terms of the GNU Lesser General Public License version 2 or 3,
@@ -14,6 +14,7 @@
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
+#include "mir/options/program_option.h"
 #include "mir/shared_library.h"
 #include "mir/options/default_configuration.h"
 #include "mir/graphics/platform.h"
@@ -21,6 +22,8 @@
 #include "mir/shared_library_prober.h"
 #include "mir/logging/null_shared_library_prober_report.h"
 
+#include <format>
+
 namespace mo = mir::options;
 
 char const* const mo::arw_server_socket_opt       = "arw-file";
@@ -44,6 +47,7 @@ char const* const mo::wayland_extensions_opt      = "wayland-extensions";
 char const* const mo::add_wayland_extensions_opt  = "add-wayland-extensions";
 char const* const mo::drop_wayland_extensions_opt = "drop-wayland-extensions";
 char const* const mo::idle_timeout_opt            = "idle-timeout";
+char const* const mo::idle_timeout_when_locked_opt = "idle-timeout-when-locked";
 
 char const* const mo::off_opt_value = "off";
 char const* const mo::log_opt_value = "log";
@@ -177,8 +181,11 @@ mo::DefaultConfiguration::DefaultConfiguration(
         (enable_key_repeat_opt, po::value<bool>()->default_value(true),
              "Enable server generated key repeat")
         (idle_timeout_opt, po::value<int>()->default_value(0),
-            "Time (in seconds) Mir will remain idle before turning off the display, "
-            "or 0 to keep display on forever.")
+            "Time (in seconds) Mir will remain idle before turning off the display "
+            "when the session is not locked, or 0 to keep display on forever.")
+        (idle_timeout_when_locked_opt, po::value<int>()->default_value(0),
+            "Time (in seconds) Mir will remain idle before turning off the display "
+            "when the session is locked, or 0 to keep the display on forever.")
         (fatal_except_opt, "On \"fatal error\" conditions [e.g. drivers behaving "
             "in unexpected ways] throw an exception (instead of a core dump)")
         (debug_opt, "Enable extra development debugging. "
@@ -200,6 +207,17 @@ mo::DefaultConfiguration::DefaultConfiguration(
         add_platform_options();
 }
 
+namespace
+{
+auto option_header_for(mir::SharedLibrary const& module) -> std::string
+{
+    auto const describe_module = module.load_function<mir::graphics::DescribeModule>("describe_graphics_module", MIR_SERVER_GRAPHICS_PLATFORM_VERSION);
+    auto const description = describe_module();
+
+    return std::format("Options for module {}", description->name);
+}
+}
+
 void mo::DefaultConfiguration::add_platform_options()
 {
     namespace po = boost::program_options;
@@ -226,13 +244,17 @@ void mo::DefaultConfiguration::add_platform_options()
 
         for (auto& platform : platform_libraries)
         {
-            /* Ideally we'd namespace these options with the platform,
-             * and display them in a group as $FOO-platform-specific.
-             */
             try
             {
                 auto add_platform_options = platform->load_function<mir::graphics::AddPlatformOptions>("add_graphics_platform_options", MIR_SERVER_GRAPHICS_PLATFORM_VERSION);
-                add_platform_options(*this->program_options);
+                auto [options, inserted] = module_options_desc.emplace(
+                    platform->get_handle(),
+                    option_header_for(*platform));
+
+                // *Pretty* sure this is impossible, but let's be sure!
+                assert(inserted && "Attempted to add platform options twice for the same module");
+
+                add_platform_options(options->second);
             }
             catch (std::runtime_error&)
             {
@@ -269,7 +291,7 @@ boost::program_options::options_description_easy_init mo::DefaultConfiguration::
     return program_options->add_options();
 }
 
-std::shared_ptr<mo::Option> mo::DefaultConfiguration::the_options() const
+std::shared_ptr<mo::Option> mo::DefaultConfiguration::global_options() const
 {
     if (!options)
     {
@@ -282,6 +304,31 @@ std::shared_ptr<mo::Option> mo::DefaultConfiguration::the_options() const
     return options;
 }
 
+auto mo::DefaultConfiguration::options_for(SharedLibrary const& module) const -> std::shared_ptr<Option>
+{
+    auto parsed_options = module_options[module.get_handle()];
+    if (!parsed_options)
+    {
+        auto options = std::make_shared<ProgramOption>();
+        auto& module_option_desc = module_options_desc.at(module.get_handle());
+
+        /* We can't combine the parsed global options with a parse of the module-specific options,
+         * but we *can* combine the global options description with the module options description
+         * and (re)parse everything against that.
+         */
+        boost::program_options::options_description joint_desc;
+        joint_desc.add(*program_options).add(module_option_desc);
+
+        parse_arguments(joint_desc, *options, argc, argv);
+        parse_environment(joint_desc, *options);
+        parse_config_file(joint_desc, *options);
+
+        module_options[module.get_handle()] = options;
+        parsed_options = options;
+    }
+
+    return parsed_options;
+}
 
 void mo::DefaultConfiguration::parse_arguments(
     boost::program_options::options_description desc,
@@ -295,21 +342,65 @@ void mo::DefaultConfiguration::parse_arguments(
     {
         desc.add_options()
             ("help,h", "this help text");
+        desc.add_options()
+            ("version,V", "display Mir version and exit");
 
         options.parse_arguments(desc, argc, argv);
 
-        auto const unparsed_arguments = options.unparsed_command_line();
+        auto unparsed_arguments = options.unparsed_command_line();
         std::vector<char const*> tokens;
         for (auto const& token : unparsed_arguments)
             tokens.push_back(token.c_str());
+
+        auto const argv0 = argc > 0 ? argv[0] : "fake argv[0]";
+        // Maybe the unparsed tokens are for a module?
+        for (auto const& [_, module_option_desc] : module_options_desc)
+        {
+            if (tokens.empty())
+            {
+                // There aren't any unparsed arguments, so we're done here
+                break;
+            }
+
+            /* We assume that argv[0] is *not* an option; instead, it's the name of the binary
+             * So when reparsing, we need to add a fake argv[0]
+             */
+            tokens.insert(tokens.begin(), argv0);
+            mo::ProgramOption tmp_options;
+            tmp_options.parse_arguments(module_option_desc, tokens.size(), tokens.data());
+
+            tokens.clear();
+            unparsed_arguments = tmp_options.unparsed_command_line();
+            for (auto const& token : unparsed_arguments)
+            {
+                tokens.push_back(token.c_str());
+            }
+        }
+
         if (!tokens.empty()) unparsed_arguments_handler(tokens.size(), tokens.data());
 
+        // See the ExitWithOutput documentation for information about its usage.
         if (options.is_set("help"))
         {
             std::ostringstream help_text;
             help_text << desc;
+            for (auto& [_, module_desc] : module_options_desc)
+            {
+                // We don't want to print out headers for platforms that don't have any options
+                if (!module_desc.options().empty())
+                {
+                    help_text << module_desc;
+                }
+            }
             BOOST_THROW_EXCEPTION(mir::ExitWithOutput(help_text.str()));
         }
+
+        if (options.is_set("version"))
+        {
+            std::ostringstream mir_version;
+            mir_version << MIR_VERSION_MAJOR << "." << MIR_VERSION_MINOR << "." << MIR_VERSION_MICRO << std::endl;
+            BOOST_THROW_EXCEPTION(mir::ExitWithOutput(mir_version.str()));
+        }
     }
     catch (po::error const& error)
     {
@@ -319,11 +410,70 @@ void mo::DefaultConfiguration::parse_arguments(
     }
 }
 
+namespace
+{
+auto is_an_option(boost::program_options::options_description const& options, std::string const& name) -> bool
+{
+    return std::find_if(
+        options.options().cbegin(),
+        options.options().cend(),
+        [&name](auto const& option) -> bool
+        {
+            return option->long_name() == name;
+        }) != options.options().cend();
+}
+}
+
 void mo::DefaultConfiguration::parse_environment(
     boost::program_options::options_description& desc,
     mo::ProgramOption& options) const
 {
-    options.parse_environment(desc, "MIR_SERVER_");
+    options.parse_environment(
+        desc,
+        [=, this](std::string const& from) -> std::string
+        {
+            auto const prefix = "MIR_SERVER_";
+            auto const sizeof_prefix = strlen(prefix);
+
+            if (!from.starts_with(prefix))
+            {
+                return std::string{};
+            }
+
+            std::string result(from, sizeof_prefix);
+
+            for(auto& ch : result)
+            {
+                if (ch == '_') ch = '-';
+                else ch = std::tolower(ch, std::locale::classic()); // avoid current locale
+            }
+
+            /* Now, we want to not fail on any options that are module-specific but
+             * not for *this* module (or for the global parse)
+             *
+             * So, we check:
+             * 1. Is the result an option in `desc` (ie: an option we're trying to parse)? Return it. Or,
+             * 2. Is the option in one of the module-specific option descriptors? Ignore it.
+             * 3. Otherwise, return it as normal, and cause a failure
+             */
+
+            if (is_an_option(desc, result))
+            {
+                return result;
+            }
+
+            // Is it an option for a different module?
+            for (auto const& [_, module_opt_desc] : module_options_desc)
+            {
+                if (is_an_option(module_opt_desc, result))
+                {
+                    // We want to ignore this for now, rather than raise an unknown option error
+                    return std::string{};
+                }
+            }
+
+            return result;
+        });
 }
 
 void mo::DefaultConfiguration::parse_config_file(
