@@ -1,5 +1,5 @@
 /*
- * Copyright © 2015-2019 Canonical Ltd.
+ * Copyright © Canonical Ltd.
  *
  * This program is free software: you can redistribute it and/or modify it
  * under the terms of the GNU General Public License version 3,
@@ -16,23 +16,28 @@
 
 #include "wayland_connector.h"
 
+#include "mir/shell/token_authority.h"
 #include "wl_client.h"
 #include "wl_data_device_manager.h"
 #include "wayland_utils.h"
 #include "wl_subcompositor.h"
 #include "wl_seat.h"
 #include "wl_region.h"
+#include "shm.h"
 #include "frame_executor.h"
 #include "output_manager.h"
 #include "wayland_executor.h"
+#include "desktop_file_manager.h"
+#include "foreign_toplevel_manager_v1.h"
+#include "wp_viewporter.h"
 
 #include "mir/main_loop.h"
 #include "mir/thread_name.h"
 #include "mir/log.h"
 #include "mir/graphics/graphic_buffer_allocator.h"
 #include "mir/frontend/wayland.h"
-#include "mir/frontend/buffer_stream_id.h"
 
+#include <optional>
 #include <sys/eventfd.h>
 #include <sys/stat.h>
 #include <sys/socket.h>
@@ -221,11 +226,14 @@ mf::WaylandConnector::WaylandConnector(
     std::shared_ptr<ObserverRegistrar<input::KeyboardObserver>> const& keyboard_observer_registrar,
     std::shared_ptr<mi::InputDeviceRegistry> const& input_device_registry,
     std::shared_ptr<mi::CompositeEventFilter> const& composite_event_filter,
+    std::shared_ptr<DragIconController> drag_icon_controller,
+    std::shared_ptr<PointerInputDispatcher> pointer_input_dispatcher,
     std::shared_ptr<mg::GraphicBufferAllocator> const& allocator,
     std::shared_ptr<mf::SessionAuthorizer> const& session_authorizer,
     std::shared_ptr<SurfaceStack> const& surface_stack,
     std::shared_ptr<ObserverRegistrar<graphics::DisplayConfigurationObserver>> const& display_config_registrar,
-    std::shared_ptr<ms::Clipboard> const& clipboard,
+    std::shared_ptr<ms::Clipboard> const& main_clipboard,
+    std::shared_ptr<ms::Clipboard> const& primary_selection_clipboard,
     std::shared_ptr<ms::TextInputHub> const& text_input_hub,
     std::shared_ptr<ms::IdleHub> const& idle_hub,
     std::shared_ptr<mc::ScreenShooter> const& screen_shooter,
@@ -233,14 +241,19 @@ mf::WaylandConnector::WaylandConnector(
     bool arw_socket,
     std::unique_ptr<WaylandExtensions> extensions_,
     WaylandProtocolExtensionFilter const& extension_filter,
-    bool enable_key_repeat)
+    std::shared_ptr<shell::AccessibilityManager> const& accessibility_manager,
+    std::shared_ptr<scene::SessionLock> const& session_lock,
+    std::shared_ptr<mir::DecorationStrategy> const& decoration_strategy,
+    std::shared_ptr<scene::SessionCoordinator> const& session_coordinator,
+    std::shared_ptr<shell::TokenAuthority> const& token_authority)
     : extension_filter{extension_filter},
       display{wl_display_create(), &cleanup_display},
       pause_signal{eventfd(0, EFD_CLOEXEC | EFD_SEMAPHORE)},
       executor{std::make_shared<WaylandExecutor>(wl_display_get_event_loop(display.get()))},
       allocator{allocator_for_display(allocator, display.get(), executor)},
       shell{shell},
-      extensions{std::move(extensions_)}
+      extensions{std::move(extensions_)},
+      session_lock_{session_lock}
 {
     if (pause_signal == mir::Fd::invalid)
     {
@@ -284,19 +297,29 @@ mf::WaylandConnector::WaylandConnector(
         input_hub,
         keyboard_observer_registrar,
         seat,
-        enable_key_repeat);
+        accessibility_manager);
     output_manager = std::make_unique<mf::OutputManager>(
         display.get(),
         executor,
         display_config_registrar);
 
-    data_device_manager_global = std::make_unique<WlDataDeviceManager>(display.get(), executor, clipboard);
+    desktop_file_manager = std::make_shared<mf::DesktopFileManager>(
+        std::make_shared<mf::GDesktopFileCache>(main_loop));
+
+    data_device_manager_global = std::make_unique<WlDataDeviceManager>(
+        display.get(),
+        executor,
+        main_clipboard,
+        std::move(drag_icon_controller),
+        std::move(pointer_input_dispatcher));
 
     extensions->init(WaylandExtensions::Context{
         display.get(),
         executor,
         shell,
-        clipboard,
+        session_authorizer,
+        main_clipboard,
+        primary_selection_clipboard,
         text_input_hub,
         idle_hub,
         seat_global.get(),
@@ -305,9 +328,18 @@ mf::WaylandConnector::WaylandConnector(
         input_device_registry,
         composite_event_filter,
         allocator,
-        screen_shooter});
+        screen_shooter,
+        main_loop,
+        desktop_file_manager,
+        session_lock_,
+        decoration_strategy,
+        session_coordinator,
+        keyboard_observer_registrar,
+        token_authority});
 
-    wl_display_init_shm(display.get());
+    shm_global = std::make_unique<WlShm>(display.get(), executor);
+
+    viewporter = std::make_unique<WpViewporter>(display.get());
 
     char const* wayland_display = nullptr;
 
@@ -494,7 +526,7 @@ void mf::WaylandConnector::on_surface_created(
     compositor_global->on_surface_created(client, id, callback);
 }
 
-auto mf::WaylandConnector::socket_name() const -> optional_value<std::string>
+auto mf::WaylandConnector::socket_name() const -> std::optional<std::string>
 {
     return wayland_display;
 }
