@@ -1,5 +1,5 @@
 /*
- * Copyright © 2013-2020 Canonical Ltd.
+ * Copyright © Canonical Ltd.
  *
  * This program is free software: you can redistribute it and/or modify it
  * under the terms of the GNU General Public License version 2 or 3,
@@ -36,8 +36,9 @@
 #include "mir/input/touch_visualizer.h"
 #include "mir/input/input_probe.h"
 #include "mir/input/platform.h"
-#include "mir/input/xkb_mapper.h"
+#include "mir/input/xkb_mapper_registrar.h"
 #include "mir/input/vt_filter.h"
+#include "mir/input/device.h"
 #include "mir/options/configuration.h"
 #include "mir/options/option.h"
 #include "mir/dispatch/multiplexing_dispatchable.h"
@@ -131,6 +132,12 @@ mir::DefaultServerConfiguration::the_surface_input_dispatcher()
         });
 }
 
+std::shared_ptr<mir::frontend::PointerInputDispatcher>
+mir::DefaultServerConfiguration::the_pointer_input_dispatcher()
+{
+    return the_surface_input_dispatcher();
+}
+
 std::shared_ptr<mi::InputDispatcher>
 mir::DefaultServerConfiguration::the_input_dispatcher()
 {
@@ -152,7 +159,7 @@ mir::DefaultServerConfiguration::the_input_dispatcher()
                 std::make_shared<mi::KeyboardResyncDispatcher>(idle_poking_dispatcher);
 
             return std::make_shared<mi::KeyRepeatDispatcher>(
-                keyboard_resync_dispatcher, the_main_loop(), the_cookie_authority(),
+                keyboard_resync_dispatcher, the_main_loop(),
                 enable_repeat, key_repeat_timeout, key_repeat_delay, false);
         });
 }
@@ -238,37 +245,14 @@ mir::DefaultServerConfiguration::the_input_manager()
                 auto const device_registry = the_input_device_registry();
                 auto const input_report = the_input_report();
 
-                // Check whether any of the already-loaded platforms are input platforms;
-                // if they are (eg: X11 or wayland), use them
-                mir::UniqueModulePtr<mi::Platform> platform;
-                for (auto const& module : the_platform_libaries())
-                {
-                    platform = mi::input_platform_from_graphics_module(
-                        *module,
-                        *options,
-                        emergency_cleanup,
-                        device_registry,
-                        the_console_services(),
-                        input_report);
-
-                    if (platform)
-                    {
-                        break;
-                    }
-                }
-
-                // otherwise (usually) we probe for it
-                if (!platform)
-                {
-                    platform = probe_input_platforms(
-                        *options,
-                        emergency_cleanup,
-                        device_registry,
-                        the_console_services(),
-                        input_report,
-                        the_platform_libaries(),
-                        *the_shared_library_prober_report());
-                }
+                auto platform = probe_input_platforms(
+                    *options,
+                    emergency_cleanup,
+                    device_registry,
+                    the_console_services(),
+                    input_report,
+                    the_platform_libaries(),
+                    *the_shared_library_prober_report());
 
                 return std::make_shared<mi::DefaultInputManager>(the_input_reading_multiplexer(), std::move(platform));
             }
@@ -329,9 +313,9 @@ std::shared_ptr<mi::DefaultInputDeviceHub> mir::DefaultServerConfiguration::the_
                the_seat(),
                the_input_reading_multiplexer(),
                the_clock(),
-               the_cookie_authority(),
                the_key_mapper(),
-               the_server_status_listener());
+               the_server_status_listener(),
+               the_led_observer_registrar());
 
            // lp:1675357: KeyRepeatDispatcher must be informed about removed input devices, otherwise
            // pressed keys get repeated indefinitely
@@ -343,13 +327,22 @@ std::shared_ptr<mi::DefaultInputDeviceHub> mir::DefaultServerConfiguration::the_
 
 std::shared_ptr<mi::KeyMapper> mir::DefaultServerConfiguration::the_key_mapper()
 {
-    return key_mapper(
-       []()
+    return xkb_mapper_registrar(
+       [default_executor=the_main_loop()]()
        {
-           return std::make_shared<mi::receiver::XKBMapper>();
+           return std::make_shared<mi::receiver::XKBMapperRegistrar>(*default_executor);
        });
 }
 
+std::shared_ptr<mi::LedObserverRegistrar> mir::DefaultServerConfiguration::the_led_observer_registrar()
+{
+    return xkb_mapper_registrar(
+        [default_executor=the_main_loop()]()
+        {
+            return std::make_shared<mi::receiver::XKBMapperRegistrar>(*default_executor);
+        });
+}
+
 std::shared_ptr<mi::SeatObserver> mir::DefaultServerConfiguration::the_seat_observer()
 {
     return seat_observer_multiplexer(
