@@ -1,5 +1,5 @@
 /*
- * Copyright © 2014-2019 Canonical Ltd.
+ * Copyright © Canonical Ltd.
  *
  * This program is free software: you can redistribute it and/or modify it
  * under the terms of the GNU General Public License version 2 or 3,
@@ -20,18 +20,16 @@
 #include "mir/fd.h"
 #include "mir/frontend/connector.h"
 #include "mir/graphics/graphic_buffer_allocator.h"
-#include "mir/graphics/display_buffer.h"
+#include "mir/graphics/display_sink.h"
 #include "mir/input/composite_event_filter.h"
 #include "mir/input/event_filter.h"
 #include "mir/options/default_configuration.h"
-#include "mir/renderer/gl/render_target.h"
 #include "mir/default_server_configuration.h"
 #include "mir/logging/logger.h"
 #include "mir/log.h"
 #include "mir/main_loop.h"
 #include "mir/report_exception.h"
 #include "mir/run_mir.h"
-#include "mir/cookie/authority.h"
 
 // TODO these are used to frig a stub renderer when running headless
 #include "mir/renderer/renderer.h"
@@ -39,10 +37,8 @@
 #include "mir/renderer/renderer_factory.h"
 
 #include "frontend_wayland/wayland_connector.h"
-
 #include <iostream>
-#include <mir/server.h>
-
+#include <optional>
 
 namespace mo = mir::options;
 namespace mi = mir::input;
@@ -101,11 +97,10 @@ struct TemporaryCompositeEventFilter : public mi::CompositeEventFilter
     MACRO(session_listener)\
     MACRO(shell)\
     MACRO(application_not_responding_detector)\
-    MACRO(cookie_authority)\
-    MACRO(persistent_surface_store)
+    MACRO(persistent_surface_store)\
+    MACRO(renderer_factory)
 
 #define FOREACH_ACCESSOR(MACRO)\
-    MACRO(the_buffer_stream_factory)\
     MACRO(the_compositor)\
     MACRO(the_compositor_report)\
     MACRO(the_cursor_listener)\
@@ -133,7 +128,14 @@ struct TemporaryCompositeEventFilter : public mi::CompositeEventFilter
     MACRO(the_application_not_responding_detector)\
     MACRO(the_persistent_surface_store)\
     MACRO(the_display_configuration_observer_registrar)\
-    MACRO(the_seat_observer_registrar)
+    MACRO(the_seat_observer_registrar)\
+    MACRO(the_session_lock)\
+    MACRO(the_renderer_factory)\
+    MACRO(the_decoration_strategy)\
+    MACRO(the_input_device_registry)\
+    MACRO(the_idle_handler)\
+    MACRO(the_token_authority)\
+    MACRO(the_accessibility_manager)
 
 #define MIR_SERVER_BUILDER(name)\
     std::function<std::invoke_result_t<decltype(&mir::DefaultServerConfiguration::the_##name),mir::DefaultServerConfiguration*>()> name##_builder;
@@ -462,7 +464,7 @@ auto mir::Server::open_wayland_client_socket() -> Fd
     BOOST_THROW_EXCEPTION(std::logic_error("Cannot open connection when not running"));
 }
 
-auto mir::Server::wayland_display() const -> optional_value<std::string>
+auto mir::Server::wayland_display() const -> std::optional<std::string>
 {
     if (auto const config = self->server_config)
         return config->the_wayland_connector()->socket_name();
@@ -470,7 +472,7 @@ auto mir::Server::wayland_display() const -> optional_value<std::string>
     BOOST_THROW_EXCEPTION(std::logic_error("Cannot open connection when not running"));
 }
 
-auto mir::Server::x11_display() const -> mir::optional_value<std::string>
+auto mir::Server::x11_display() const -> std::optional<std::string>
 {
     if (auto const config = self->server_config)
         return config->the_xwayland_connector()->socket_name();
@@ -478,6 +480,16 @@ auto mir::Server::x11_display() const -> mir::optional_value<std::string>
     BOOST_THROW_EXCEPTION(std::logic_error("Cannot open connection when not running"));
 }
 
+auto mir::Server::get_activation_token() const -> std::string
+{
+    if (auto const config = self->server_config)
+    {
+        return std::string(config->the_token_authority()->issue_token({}));
+    }
+
+    BOOST_THROW_EXCEPTION(std::logic_error("Cannot open connection when not running"));
+}
+
 void mir::Server::run_on_wayland_display(std::function<void(wl_display*)> const& functor)
 {
     if (auto const config = self->server_config)
@@ -743,5 +755,25 @@ void mir::Server::add_configuration_option(
             self->set_add_configuration_options(option_adder);
         }
         break;
+
+        case OptionType::real:
+        {
+            auto const option_adder = [=](options::DefaultConfiguration& config)
+            {
+                existing(config);
+
+                config.add_options()
+                        (option.c_str(), po::value<double>(), description.c_str());
+            };
+
+            self->set_add_configuration_options(option_adder);
+        }
+        break;
     }
 }
+
+
+void mir::Server::set_the_decoration_strategy(std::shared_ptr<DecorationStrategy> strategy)
+{
+    self->server_config->set_the_decoration_strategy(strategy);
+}
