@@ -1,5 +1,5 @@
 /*
- * Copyright © 2013-2017 Canonical Ltd.
+ * Copyright © Canonical Ltd.
  *
  * This program is free software: you can redistribute it and/or modify it
  * under the terms of the GNU General Public License version 2 or 3,
@@ -14,20 +14,23 @@
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
-#include <mir/shell/system_compositor_window_manager.h>
-#include <mir/main_loop.h>
 #include "mir/default_server_configuration.h"
-#include "mir/abnormal_exit.h"
 
-#include "mir/input/composite_event_filter.h"
-#include "mir/shell/abstract_shell.h"
-#include "mir/options/configuration.h"
-#include "mir/options/option.h"
+#include "basic_idle_handler.h"
+#include "decoration/basic_decoration.h"
+#include "decoration/basic_manager.h"
 #include "default_persistent_surface_store.h"
 #include "graphics_display_layout.h"
-#include "decoration/basic_manager.h"
-#include "decoration/basic_decoration.h"
-#include "basic_idle_handler.h"
+
+#include "mir/abnormal_exit.h"
+#include "mir/input/composite_event_filter.h"
+#include "mir/main_loop.h"
+#include "mir/options/configuration.h"
+#include "mir/options/option.h"
+#include "mir/shell/abstract_shell.h"
+#include "mir/shell/accessibility_manager.h"
+#include "mir/shell/system_compositor_window_manager.h"
+#include "mir/shell/token_authority.h"
 
 namespace ms = mir::scene;
 namespace msh = mir::shell;
@@ -70,9 +73,12 @@ auto mir::DefaultServerConfiguration::the_decoration_manager() -> std::shared_pt
         [this]()->std::shared_ptr<msd::Manager>
         {
             return std::make_shared<msd::BasicManager>(
+                msd::DecorationStrategy::default_decoration_strategy(),
+                *the_display_configuration_observer_registrar(),
                 [buffer_allocator = the_buffer_allocator(),
                  executor = the_main_loop(),
                  cursor_images = the_cursor_images()](
+                    std::shared_ptr<msd::DecorationStrategy> const& decoration_strategy,
                     std::shared_ptr<shell::Shell> const& shell,
                     std::shared_ptr<scene::Surface> const& surface) -> std::unique_ptr<msd::Decoration>
                 {
@@ -81,7 +87,8 @@ auto mir::DefaultServerConfiguration::the_decoration_manager() -> std::shared_pt
                         buffer_allocator,
                         executor,
                         cursor_images,
-                        surface);
+                        surface,
+                        decoration_strategy);
                 });
         });
 }
@@ -99,7 +106,8 @@ auto mir::DefaultServerConfiguration::the_idle_handler() -> std::shared_ptr<msh:
                 the_idle_hub(),
                 the_input_scene(),
                 the_buffer_allocator(),
-                the_display_configuration_controller());
+                the_display_configuration_controller(),
+                the_session_lock());
 
             auto options = the_options();
             int const idle_timeout_seconds = options->get<int>(options::idle_timeout_opt);
@@ -121,10 +129,37 @@ auto mir::DefaultServerConfiguration::the_idle_handler() -> std::shared_ptr<msh:
                 idle_handler->set_display_off_timeout(std::chrono::seconds{idle_timeout_seconds});
             }
 
+            int const idle_timeout_when_locked = options->get<int>(options::idle_timeout_when_locked_opt);
+            if (idle_timeout_when_locked < 0)
+            {
+                throw mir::AbnormalExit(
+                    "Invalid " +
+                    std::string{options::idle_timeout_when_locked_opt} +
+                    " value " +
+                    std::to_string(idle_timeout_when_locked) +
+                    ", must be > 0");
+            }
+            if (idle_timeout_when_locked == 0)
+            {
+                idle_handler->set_display_off_timeout_when_locked(std::nullopt);
+            }
+            else
+            {
+                idle_handler->set_display_off_timeout_when_locked(std::chrono::seconds{idle_timeout_when_locked});
+            }
+
             return idle_handler;
         });
 }
 
+auto mir::DefaultServerConfiguration::the_token_authority() -> std::shared_ptr<msh::TokenAuthority>
+{
+    return token_authority([this]()
+        {
+            return std::make_shared<msh::TokenAuthority>(the_main_loop());
+        });
+}
+
 std::shared_ptr<msh::PersistentSurfaceStore>
 mir::DefaultServerConfiguration::the_persistent_surface_store()
 {
@@ -150,3 +185,12 @@ mir::DefaultServerConfiguration::the_shell_display_layout()
         });
 }
 
+auto mir::DefaultServerConfiguration::the_accessibility_manager() -> std::shared_ptr<shell::AccessibilityManager>
+{
+    return accessibility_manager(
+        []
+        {
+            return std::make_shared<shell::AccessibilityManager>();
+        });
+}
+
